@@ -148,7 +148,6 @@ load_image (gchar *fname,
 					    GTK_BUTTONS_OK,
 					    message,
 					    NULL);
-		gtk_dialog_set_has_separator (GTK_DIALOG (w), FALSE);
 		gtk_dialog_run (GTK_DIALOG (w));	
 		g_free (message);
 		exit (1);
@@ -518,6 +517,11 @@ button_press_event (GtkWidget *widget, GdkEvent *event)
 	/* XXX Ezt megkapja */
 
 	if(inmove) return TRUE;
+
+	/* Ignore the 2BUTTON and 3BUTTON events. */
+	if (event->type != GDK_BUTTON_PRESS)
+		return TRUE;
+	
 	gtk_widget_get_pointer (widget, &x, &y);
 	fx = x / boxsize;
 	fy = y / boxsize;
@@ -871,7 +875,7 @@ game_about_callback (GtkWidget *widget, void *data)
                            NULL
                           };
    /* Translator credits */
-   gchar *translator_credits = _("translator_credits");
+   gchar *translator_credits = _("translator-credits");
 
    if (about != NULL) {
         gtk_window_present (GTK_WINDOW(about));
@@ -891,12 +895,12 @@ game_about_callback (GtkWidget *widget, void *data)
    }
    					        
 	about = gnome_about_new (_("Glines"), VERSION,
-			"Copyright \xc2\xa9 1997-2003 Free Software "
+			"Copyright \xc2\xa9 1997-2004 Free Software "
 			"Foundation, Inc.",
 			_("GNOME port of the once-popular Color Lines game"),
 			(const char **)authors,
 			(const char **)documenters,
-			strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+			strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
 		        pixbuf);
 	
 	if (pixbuf != NULL)
@@ -961,7 +965,7 @@ bg_color_callback (GtkWidget *widget, gpointer data)
 
 	gtk_color_button_get_color (GTK_COLOR_BUTTON (widget), &c);
 
-	tmp = g_strdup_printf ("#%02x%02x%02x", c.red, c.green, c.blue);
+	tmp = g_strdup_printf ("#%04x%04x%04x", c.red, c.green, c.blue);
 
 	gconf_client_set_string (conf_client,
 				 KEY_BACKGROUND_COLOR, tmp, NULL);
