@@ -75,7 +75,7 @@ Tetris::Tetris(int cmdlLevel):
 	field(0),
 	preview(0),
 	paused(false), 
-	timeoutId(-1), 
+	timeoutId(0), 
 	onePause(false), 
 	inPlay(false),
 	image(0),
@@ -85,12 +85,17 @@ Tetris::Tetris(int cmdlLevel):
 	fastFall(false),
         dropBlock(false)
 {
+	double x1, y1, x2, y2;
+	double width;
+	double pts;
+
 	pic = new GdkPixbuf*[tableSize];
 	for (int i = 0; i < tableSize; ++i)
 		pic[i] = 0;
 	
 	w = gnome_app_new("gnometris", _("Gnometris"));
 	g_signal_connect (w, "delete_event", G_CALLBACK (gameQuit), this);
+	gtk_window_set_resizable (GTK_WINDOW (w), FALSE);
 
 	static GnomeUIInfo game_menu[] = 
 	{
@@ -116,7 +121,7 @@ Tetris::Tetris(int cmdlLevel):
 	
 	GnomeUIInfo help_menu[] = 
 	{
-		/* FIXME GNOMEUIINFO_HELP((gpointer)"gnometris"), */
+		GNOMEUIINFO_HELP((gpointer)"gnometris"),
 		GNOMEUIINFO_MENU_ABOUT_ITEM(gameAbout, this),
 		GNOMEUIINFO_END
 	};
@@ -199,6 +204,22 @@ Tetris::Tetris(int cmdlLevel):
                                               "size_points", 36.0,
                                               0
                                               );
+
+	/* Since gnome_canvas doesn't support setting the size of text in
+	 * pixels (read the source where the "size" parameter gets set)
+	 * and pango isn't forthcoming about how it scales things (see
+	 * http://mail.gnome.org/archives/gtk-i18n-list/2003-August/msg00001.html
+	 * and bug #119081). We guess at the size, see what size it is rendered
+	 * to and then adjust the point size to fit. 36.0 points is pretty
+	 * close for 96 dpi . */
+
+	gnome_canvas_item_get_bounds (pauseMessage, &x1, &y1, &x2, &y2);
+	width = x2 - x1;
+	/* 0.8 is the fraction of the screen we want to use and 36.0 is
+	 * the guess we use previously for the point size. */
+	pts = 0.8*36.0*COLUMNS*BLOCK_SIZE/width;
+	gnome_canvas_item_set (pauseMessage, "size_points", pts, 0);
+
         gnome_canvas_item_hide (pauseMessage);
 
         gameoverMessage = gnome_canvas_item_new (gnome_canvas_root(GNOME_CANVAS(field->getWidget())),
@@ -211,6 +232,14 @@ Tetris::Tetris(int cmdlLevel):
                                                  "size_points", 36.0,
                                                  0
                                                  );
+
+	gnome_canvas_item_get_bounds (gameoverMessage, &x1, &y1, &x2, &y2);
+	width = x2 - x1;
+	/* 0.9 is the fraction of the screen we want to use and 36.0 is
+	 * the guess we use previously for the point size. */
+	pts = 0.9*36.0*COLUMNS*BLOCK_SIZE/width;
+	gnome_canvas_item_set (gameoverMessage, "size_points", pts, 0);
+
         gnome_canvas_item_hide (gameoverMessage);
 
 }
@@ -261,13 +290,12 @@ Tetris::setupdialogDestroy(GtkWidget *widget, void *d)
 	if (t->setupdialog)
 		gtk_widget_destroy(t->setupdialog);
 	t->setupdialog = 0;
+	gtk_widget_set_sensitive(t->gameMenuPtr[0].widget, TRUE);
 }
 
 void
 Tetris::setupdialogResponse (GtkWidget *dialog, gint response_id, void *d)
 {
-	Tetris *t = (Tetris *) d;
-
 	setupdialogDestroy (NULL, d);
 }
 
@@ -288,7 +316,6 @@ Tetris::setupPixmap()
 						       GTK_MESSAGE_ERROR,
 						       GTK_BUTTONS_OK,
 						       _("Could not find the theme: \n%s\n\nPlease check your gnome-games installation"), fullpixname);
-		gtk_dialog_set_has_separator (GTK_DIALOG (w), FALSE);
 		gtk_dialog_run (GTK_DIALOG (w));
 		exit(1);
 	}
@@ -304,7 +331,6 @@ Tetris::setupPixmap()
 						       GTK_MESSAGE_ERROR,
 						       GTK_BUTTONS_OK,
 						       _("Can't load the image: \n%s\n\nPlease check your gnome-games installation"), fullpixname);
-		gtk_dialog_set_has_separator (GTK_DIALOG (w), FALSE);
 		gtk_dialog_run (GTK_DIALOG (w));
 		exit (1);
 	}
@@ -357,24 +383,14 @@ Tetris::setupPixmap()
 	if (field)
 	{
 		field->updateSize (bgimage);
-		gtk_widget_queue_draw (field->getWidget());
+		gtk_widget_queue_resize (field->getWidget());
 	}
 	
 	if (preview)
 	{
 		preview->updateSize ();
-		gtk_widget_queue_draw (preview->getWidget());
+		gtk_widget_queue_resize (field->getWidget());
 	}
-
-	// FIXME: this really sucks, but I can't find a better way to resize 
-	// all widgets after the block pixmap change
-	if (scoreFrame)
-	{
-		int l = scoreFrame->getLevel();
-		scoreFrame->setLevel(l + 1);
-		scoreFrame->setLevel(l);
-	}
-	
 }
 
 void
@@ -591,7 +607,6 @@ Tetris::fillMenu(GtkWidget *menu, char *pixname, char *dirname,
 	if (!dir)
 		return;
 	
-	GtkWidget *item;
 	char *s;
 	
 	while ((e = readdir (dir)) != 0)
@@ -627,12 +642,10 @@ Tetris::fillMenu(GtkWidget *menu, char *pixname, char *dirname,
 int 
 Tetris::gameProperties(GtkWidget *widget, void *d)
 {
-	GtkWidget *allBoxes;
-	GtkWidget *box, *box2;
 	GtkWidget *label;
 	GtkWidget *frame;
 	GtkWidget *table;
-	GtkWidget *hbox, *fvbox, *space_label;
+	GtkWidget *fvbox;
 	GtkObject *adj;
         
 	Tetris *t = (Tetris*) d;
@@ -784,6 +797,7 @@ Tetris::gameProperties(GtkWidget *widget, void *d)
 			    FALSE, FALSE, 0);
 	
 	gtk_widget_show_all (t->setupdialog);
+	gtk_widget_set_sensitive(t->gameMenuPtr[0].widget, FALSE);
 	return TRUE;
 }
 
@@ -801,7 +815,7 @@ Tetris::gameEnd(GtkWidget *widget, void *d)
 	Tetris *t = (Tetris*) d;
 	
 	g_source_remove(t->timeoutId);
-	t->timeoutId = -1;
+	t->timeoutId = 0;
 	blocknr_next = -1;
 	t->endOfGame();
 	return TRUE;
@@ -855,7 +869,7 @@ Tetris::timeoutHandler(void *d)
 	Tetris *t = (Tetris*) d;
 	
 	if (t->paused)
-		return 1;
+		return TRUE;
 
  	if (t->onePause)
  	{
@@ -879,7 +893,7 @@ Tetris::timeoutHandler(void *d)
 			++t->fastFallPoints;
 	}
 
-	return 1;	
+	return TRUE;	
 }
 
 gint
@@ -888,7 +902,7 @@ Tetris::eventHandler(GtkWidget *widget, GdkEvent *event, void *d)
 	Tetris *t = (Tetris*) d;
         int bonus;
         
-	if (t->timeoutId == -1)
+	if (t->timeoutId == 0)
 		return FALSE;
 	
 	if (event->type == GDK_KEY_PRESS)
@@ -1009,7 +1023,7 @@ Tetris::generate()
 	else
 	{
 		g_source_remove(timeoutId);
-		timeoutId = -1;
+		timeoutId = 0;
 		blocknr_next = -1;
 		
 		endOfGame();
@@ -1057,7 +1071,7 @@ Tetris::gameNew(GtkWidget *widget, void *d)
 	if (t->timeoutId) 
 	{
 		g_source_remove(t->timeoutId);
-		t->timeoutId = -1;
+		t->timeoutId = 0;
 
 		/* Catch the case where we started a new game without
 		 * finishing the old one. */
@@ -1107,7 +1121,7 @@ Tetris::gameAbout(GtkWidget *widget, void *d)
 		NULL
 	};
 
-	const gchar *translator_credits = _("translator_credits");
+	const gchar *translator_credits = _("translator-credits");
 
 	if (about != NULL) {
 		gtk_window_present (GTK_WINDOW(about));
@@ -1135,7 +1149,7 @@ Tetris::gameAbout(GtkWidget *widget, void *d)
 				  "janusz.gorycki@intel.com"),
 				(const char **)authors,
 				(const char **)documenters,
-				strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+				strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
 				pixbuf);
 	
 	if (pixbuf != NULL)
