@@ -1622,9 +1622,14 @@ about_callback (GtkWidget *widget, gpointer data)
 		"Michael Meeks",
                 "Philippe Chavin",
 		"Callum McKenzie",
+		"Rexford Newbould",
+		"Krzysztof Foltman",
 		"",
 		N_("Tiles:"),
 		"Jonathan Buzzard",
+		"Jim Evans",
+		"Richard Hoelscher",
+		"Gonzalo Odiard",
 		"Max Watson",
 		NULL
 	};
@@ -1653,7 +1658,7 @@ about_callback (GtkWidget *widget, gpointer data)
 	}
 	
 	about = gnome_about_new (_("GNOME Mahjongg"), VERSION,
-				 "Copyright \xc2\xa9 1998-2003 Free Software "
+				 "Copyright \xc2\xa9 1998-2004 Free Software "
 				 "Foundation, Inc.",
 				 _("GNOME version of the Eastern tile game, "
 				   "Mahjongg."),
